.. _credits-label:

**wavy** usage examples
=======================

If you are using **wavy** please mention the repo under https://github.com/bohlinger/wavy and for info from the documentation refer to this page `https://wavyopen.readthedocs.io/ <https://wavyopen.readthedocs.io/en/latest/index.html>`_. Additionally, the collocation methodology should be referred to with the following article: 

* Bohlinger, P., Breivik, Ø., Economou, T., Müller, M. (2019). `A novel approach to computing super observations for probabilistic wave model validation <https://www.sciencedirect.com/science/article/pii/S1463500319300435>`_, Ocean Modelling, 139, `<https://doi.org/10.1016/j.ocemod.2019.101404>`_.


Scientific papers that used **wavy**
************************************
* Hope, G., Seldal, T., Rabault, J., Bryhni, H., Bohlinger, P., Björkqvist, J.-V., and Coauthors, 2025: SFY—A Lightweight, High-Frequency, and Phase-Resolving Wave Buoy for Coastal Waters. J. Atmos. Oceanic Technol., 42, 133–154, https://doi.org/10.1175/JTECH-D-23-0170.1.
* Altiparmaki, O., Breivik, Ø., Aouf, L., Bohlinger, P., Johannessen, J. A., Collard, F., and Coauthors (2024). Influence of ocean currents on wave modeling and satellite observations: Insights from the one ocean expedition. Journal of Geophysical Research: Oceans, 129, e2024JC021581. https://doi.org/10.1029/2024JC021581
* Ølberg, J.T., Bohlinger, P., Breivik, Ø., and Coauthors (2024). Wave measurements using open source ship mounted ultrasonic altimeter and motion correction system during the one ocean circumnavigation. Ocean Engineering, 292, https://doi.org/10.1016/j.oceaneng.2023.116586.
* Rabault, J., and Coauthors (2022). Openmetbuoy-v2021: An easy-to-build, affordable, customizable, open-source instrument for oceanographic measurements of drift and waves in sea ice and the open ocean. Geosciences, 12 (3).
* Breivik, Ø., and Coauthors (2022). The impact of a reduced high-wind charnock parameter on wave growth with application to the north sea, the norwegian sea and the arctic ocean. Journal of Geophysical Research: Oceans, e2021JC018196.
* Halsne, T., Bohlinger, P., Christensen, K.H., Carrasco, A., Breivik, Ø. (2022). Resolving regions known for intense wave–current interaction using spectral wave models: A case study in the energetic flow fields of Northern Norway, Ocean Modelling,Volume 176.
* Thomas, E. E., Müller, M., Bohlinger, P., Batrak, Y., & Szapiro, N. (2021). A Kilometer-Scale Coupled Atmosphere–Wave Forecasting System for the European Arctic. Weather and Forecasting, 36(6), 2087-2099.
* Bohlinger, P., Breivik, Ø., Economou, T., Müller, M. (2019). `A novel approach to computing super observations for probabilistic wave model validation <https://www.sciencedirect.com/science/article/pii/S1463500319300435>`_, Ocean Modelling, 139, `<https://doi.org/10.1016/j.ocemod.2019.101404>`_.

Master thesis using wavy
************************
Judith Thu Ølberg, 2023: Wave Measurements Using Ship Mounted Sensors as part of the One Ocean Expedition, University of Bergen, https://hdl.handle.net/11250/3071001.

Copernicus CMEMS Product Quality Documents QuID
***********************************************
* Arctic Ocean Wave Hindcast system, ARCTIC_MULTIYEAR_WAV_002_013, https://doi.org/10.48670/moi-00008
* Arctic Ocean Wave Analysis and Forecast, ARCTIC_ANALYSIS_FORECAST_WAV_002_014, https://doi.org/10.48670/moi-00002

Internal usage at MET Norway
****************************
* operational validation of wave models
* project based validation of wave models
* operational and project based tuning of wave models

Public operational validation tasks using **wavy**
**************************************************
Operational model validation for the Copernicus CMEMS product ARCTIC_ANALYSIS_FORECAST_WAV_002_014 (https://cmems.met.no/ARC-MFC/Wave3kmValidation/index.html)

**wavy**-based operational validation and education via capacity building project SAREPTA
*****************************************************************************************
* Vietnam Meteorological and Hydrological Administration (VNMHA)
* VNU University of Science (a part of Vietnam National University). The Department of Meteorology, Hydrology and Oceanography uses the **wavy** to validate and calibrate wave models.
* The Marine Dynamics and Environment Center (MDEC)
* Mozambique (workshops)

Projects **wavy** is/was contributing to
****************************************
* Copernicus - CMEMS/ARC MFC (Arctic Monitoring Forecasting Centre) [EU]
* FORESEE - Young Research Talents Grant [NFR - Norwegian Research Council]
* COSY - Project on coastal altimetry from the [NOSA - Norwegian Space Agency]
* B-WAVES - National Project [NFR]
* SAREPTA - Large capacity building project (https://bistand.met.no/) [NORAD - The Norwegian Agency for Development Cooperation]
* One Ocean Expedition - UN Decade of Ocean Science for Sustainable Development
